

################################################################################
################################################################################
#
# Dependencies
#


#' @importFrom pkgutils L LL must case sections listing pkg_files flatten
#'
NULL

#' @importFrom pkgutils mypdf
#'
NULL

#' @import grofit
#'
NULL

#' @importFrom stats aggregate optimize kmeans heatmap update reshape var
#'
NULL

#' @importFrom stats lm glm aov confint
#'
NULL

#' @importFrom parallel mclapply
#'
NULL

#' @importFrom boot boot boot.ci norm.ci
#'
NULL

#' @importFrom Ckmeans.1d.dp Ckmeans.1d.dp
#'
NULL

#' @importFrom hwriter hmakeTag hwrite
#'
NULL

#' @importFrom lattice xyplot strip.custom panel.grid panel.abline panel.xyplot
#'
NULL

#' @importFrom lattice levelplot
#'
NULL

#' @importFrom plotrix radial.plot
#'
NULL

#' @importFrom yaml as.yaml yaml.load yaml.load_file
#'
NULL

#' @importFrom rjson toJSON
#'
NULL

#' @importFrom splines spline.des
#'
NULL

#' @import mgcv
#'
NULL
